@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
-# Copyright (c) 2008-2019 pyglet contributors
+# Copyright (c) 2008-2022 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -128,24 +128,18 @@ Retrieving data with the format and pitch given in `ImageData.format` and
 use of the data in this arbitrary format).
 
 """
-
-from __future__ import division
-from builtins import bytes
-from builtins import zip
-
-__docformat__ = 'restructuredtext'
-__version__ = '$Id$'
-
-from io import open
 import re
 import weakref
 
 from ctypes import *
+from io import open, BytesIO
+from functools import lru_cache
+
+import pyglet
 
 from pyglet.gl import *
 from pyglet.gl import gl_info
-from pyglet.window import *
-from pyglet.compat import asbytes, bytes_type, BytesIO
+from pyglet.util import asbytes
 
 from .codecs import ImageEncodeException, ImageDecodeException
 from .codecs import add_default_image_codecs, add_decoders, add_encoders
@@ -274,6 +268,7 @@ def create(width, height, pattern=None):
     return pattern.create_image(width, height)
 
 
+@lru_cache()
 def get_max_texture_size():
     """Query the maximum texture size available"""
     size = c_int()
@@ -281,15 +276,14 @@ def get_max_texture_size():
     return size.value
 
 
+@lru_cache()
 def _color_as_bytes(color):
-    if sys.version.startswith('2'):
-        return '%c%c%c%c' % color
-    else:
-        if len(color) != 4:
-            raise TypeError("color is expected to have 4 components")
-        return bytes(color)
+    if len(color) != 4:
+        raise TypeError("color is expected to have 4 components")
+    return bytes(color)
 
 
+@lru_cache()
 def _nearest_pow2(v):
     # From http://graphics.stanford.edu/~seander/bithacks.html#RoundUpPowerOf2
     # Credit: Sean Anderson
@@ -302,12 +296,13 @@ def _nearest_pow2(v):
     return v + 1
 
 
+@lru_cache()
 def _is_pow2(v):
     # http://graphics.stanford.edu/~seander/bithacks.html#DetermineIfPowerOf2
     return (v & (v - 1)) == 0
 
 
-class ImagePattern(object):
+class ImagePattern:
     """Abstract image creation class."""
 
     def create_image(self, width, height):
@@ -373,7 +368,7 @@ class CheckerImagePattern(ImagePattern):
         return ImageData(width, height, 'RGBA', data)
 
 
-class AbstractImage(object):
+class AbstractImage:
     """Abstract class representing an image.
 
     :Parameters:
@@ -545,7 +540,7 @@ class AbstractImage(object):
         raise ImageException('Cannot blit %r to a texture.' % self)
 
 
-class AbstractImageSequence(object):
+class AbstractImageSequence:
     """Abstract sequence of images.
 
     The sequence is useful for storing image animations or slices of a volume.
@@ -962,7 +957,7 @@ class ImageData(AbstractImage):
                 format, type = self._get_gl_format_and_type(data_format)
 
         # Workaround: don't use GL_UNPACK_ROW_LENGTH
-        if gl.current_context._workaround_unpack_row_length:
+        if pyglet.gl.current_context._workaround_unpack_row_length:
             data_pitch = self.width * len(data_format)
 
         # Get data in required format (hopefully will be the same format it's
@@ -1054,8 +1049,8 @@ class ImageData(AbstractImage):
             packed_pitch = self.width * len(current_format)
             if abs(self._current_pitch) != packed_pitch:
                 # Pitch is wider than pixel data, need to go row-by-row.
-                rows = re.findall(
-                    asbytes('.') * abs(self._current_pitch), data, re.DOTALL)
+                new_pitch = abs(self._current_pitch)
+                rows = [data[i:i+new_pitch] for i in range(0, len(data), new_pitch)]
                 rows = [swap_pattern.sub(repl, r[:packed_pitch]) for r in rows]
                 data = asbytes('').join(rows)
             else:
@@ -1069,26 +1064,26 @@ class ImageData(AbstractImage):
             diff = abs(current_pitch) - abs(pitch)
             if diff > 0:
                 # New pitch is shorter than old pitch, chop bytes off each row
-                pattern = re.compile(
-                    asbytes('(%s)%s' % ('.' * abs(pitch), '.' * diff)), re.DOTALL)
-                data = pattern.sub(asbytes(r'\1'), data)
+                new_pitch = abs(pitch)
+                rows = [data[i:i+new_pitch-diff] for i in range(0, len(data), new_pitch)]
             elif diff < 0:
                 # New pitch is longer than old pitch, add '0' bytes to each row
-                pattern = re.compile(
-                    asbytes('(%s)' % ('.' * abs(current_pitch))), re.DOTALL)
-                pad = '.' * -diff
-                data = pattern.sub(asbytes(r'\1%s' % pad), data)
+                new_pitch = abs(current_pitch)
+                padding = asbytes(1) * -diff
+                rows = [data[i:i+new_pitch] + padding for i in range(0, len(data), new_pitch)]
 
             if current_pitch * pitch < 0:
                 # Pitch differs in sign, swap row order
-                rows = [data[i:i+abs(pitch)] for i in range(0, len(data), abs(pitch))]
+                new_pitch = abs(pitch)
+                rows = [data[i:i+new_pitch] for i in range(0, len(data), new_pitch)]
                 rows.reverse()
-                data = asbytes('').join(rows)
+            
+            data = asbytes('').join(rows)
 
         return asbytes(data)
 
     def _ensure_string_data(self):
-        if type(self._current_data) is not bytes_type:
+        if type(self._current_data) is not bytes:
             buf = create_string_buffer(len(self._current_data))
             memmove(buf, self._current_data, len(self._current_data))
             self._current_data = buf.raw
@@ -1173,7 +1168,8 @@ class ImageDataRegion(ImageData):
 
         self._ensure_string_data()
         data = self._convert(self._current_format, abs(self._current_pitch))
-        rows = re.findall(b'.' * abs(self._current_pitch), data, re.DOTALL)
+        new_pitch = abs(self._current_pitch)
+        rows = [data[i:i+new_pitch] for i in range(0, len(data), new_pitch)]
         rows = [row[x1:x2] for row in rows[self.y:self.y + self.height]]
         self._current_data = b''.join(rows)
         self._current_pitch = self.width * len(self._current_format)
@@ -1397,7 +1393,7 @@ class Texture(AbstractImage):
         super(Texture, self).__init__(width, height)
         self.target = target
         self.id = id
-        self._context = gl.current_context
+        self._context = pyglet.gl.current_context
 
     def __del__(self):
         try:
@@ -1893,7 +1889,7 @@ class DepthTexture(Texture):
         source.blit_to_texture(self.level, x, y, z)
 
 
-class BufferManager(object):
+class BufferManager:
     """Manages the set of framebuffers for a context.
 
     Use :py:func:`~pyglet.image.get_buffer_manager` to obtain the instance of this class for the
@@ -2008,7 +2004,7 @@ def get_buffer_manager():
     
     :rtype: :py:class:`~pyglet.image.BufferManager`
     """
-    context = gl.current_context
+    context = pyglet.gl.current_context
     if not hasattr(context, 'image_buffer_manager'):
         context.image_buffer_manager = BufferManager()
     return context.image_buffer_manager
