@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------
 # pyglet
 # Copyright (c) 2006-2008 Alex Holkner
-# Copyright (c) 2008-2019 pyglet contributors
+# Copyright (c) 2008-2022 pyglet contributors
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,6 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 # ----------------------------------------------------------------------------
-# $Id:$
 
 """Formatted and unformatted document interfaces used by text layout.
 
@@ -41,7 +40,7 @@ Abstract representation
 
 Styled text in pyglet is represented by one of the :py:class:`~pyglet.text.document.AbstractDocument` classes,
 which manage the state representation of text and style independently of how
-it is loaded or rendered.  
+it is loaded or rendered.
 
 A document consists of the document text (a Unicode string) and a set of
 named style ranges.  For example, consider the following (artificial)
@@ -132,7 +131,7 @@ entire paragraph, otherwise results are undefined.
 ``align``
     ``left`` (default), ``center`` or ``right``.
 ``indent``
-    Additional horizontal space to insert before the first 
+    Additional horizontal space to insert before the first
 ``leading``
     Additional space to insert between consecutive lines within a paragraph,
     in points.  Defaults to 0.
@@ -160,15 +159,10 @@ document; it will be ignored by the built-in text classes.
 
 All style attributes (including those not present in a document) default to
 ``None`` (including the so-called "boolean" styles listed above).  The meaning
-of a ``None`` style is style- and application-dependent. 
+of a ``None`` style is style- and application-dependent.
 
 .. versionadded:: 1.1
 """
-from builtins import next
-from builtins import object
-
-__docformat__ = 'restructuredtext'
-__version__ = '$Id: $'
 
 import re
 import sys
@@ -182,13 +176,13 @@ _is_pyglet_doc_run = hasattr(sys, "is_pyglet_doc_run") and sys.is_pyglet_doc_run
 STYLE_INDETERMINATE = 'indeterminate'
 
 
-class InlineElement(object):
+class InlineElement:
     """Arbitrary inline element positioned within a formatted document.
 
     Elements behave like a single glyph in the document.  They are
     measured by their horizontal advance, ascent above the baseline, and
-    descent below the baseline.  
-    
+    descent below the baseline.
+
     The pyglet layout classes reserve space in the layout for elements and
     call the element's methods to ensure they are rendered at the
     appropriate position.
@@ -231,8 +225,8 @@ class InlineElement(object):
 
         It is the responsibility of the element to clip itself against
         the layout boundaries, and position itself appropriately with respect
-        to the layout's position and viewport offset.  
-        
+        to the layout's position and viewport offset.
+
         The `TextLayout.top_state` graphics state implements this transform
         and clipping into window space.
 
@@ -269,7 +263,7 @@ class AbstractDocument(event.EventDispatcher):
     This class can be overridden to interface pyglet with a third-party
     document format.  It may be easier to implement the document format in
     terms of one of the supplied concrete classes :py:class:`~pyglet.text.document.FormattedDocument` or
-    :py:class:`~pyglet.text.document.UnformattedDocument`. 
+    :py:class:`~pyglet.text.document.UnformattedDocument`.
     """
     _previous_paragraph_re = re.compile(u'\n[^\n\u2029]*$')
     _next_paragraph_re = re.compile(u'[\n\u2029]')
@@ -475,8 +469,7 @@ class AbstractDocument(event.EventDispatcher):
                 inserted text.
 
         """
-        assert element._position is None, \
-            'Element is already in a document.'
+        assert element._position is None, 'Element is already in a document.'
         self.insert_text(position, '\0', attributes)
         element._position = position
         self._elements.append(element)
@@ -620,8 +613,9 @@ class UnformattedDocument(AbstractDocument):
         font_size = self.styles.get('font_size')
         bold = self.styles.get('bold', False)
         italic = self.styles.get('italic', False)
+        stretch = self.styles.get('stretch', False)
         return font.load(font_name, font_size,
-                         bold=bool(bold), italic=bool(italic), dpi=dpi)
+                         bold=bold, italic=italic, stretch=stretch, dpi=dpi)
 
     def get_element_runs(self):
         return runlist.ConstRunIterator(len(self._text), None)
@@ -665,11 +659,12 @@ class FormattedDocument(AbstractDocument):
             self.get_style_runs('font_size'),
             self.get_style_runs('bold'),
             self.get_style_runs('italic'),
+            self.get_style_runs('stretch'),
             dpi)
 
     def get_font(self, position, dpi=None):
-        iter = self.get_font_runs(dpi)
-        return iter[position]
+        runs_iter = self.get_font_runs(dpi)
+        return runs_iter[position]
 
     def get_element_runs(self):
         return _ElementIterator(self._elements, len(self._text))
@@ -686,8 +681,7 @@ class FormattedDocument(AbstractDocument):
                 try:
                     runs = self._style_runs[attribute]
                 except KeyError:
-                    runs = self._style_runs[attribute] = \
-                        runlist.RunList(0, None)
+                    runs = self._style_runs[attribute] = runlist.RunList(0, None)
                     runs.insert(0, len(self.text))
                 runs.set_run(start, start + len_text, value)
 
@@ -713,31 +707,26 @@ class _ElementIterator(runlist.RunIterator):
         self.start, self.end, self.value = next(self)
 
 
-class _FontStyleRunsRangeIterator(object):
+class _FontStyleRunsRangeIterator:
     # XXX subclass runlist
-    def __init__(self, font_names, font_sizes, bolds, italics, dpi):
-        self.zip_iter = runlist.ZipRunIterator(
-            (font_names, font_sizes, bolds, italics))
+    def __init__(self, font_names, font_sizes, bolds, italics, stretch, dpi):
+        self.zip_iter = runlist.ZipRunIterator((font_names, font_sizes, bolds, italics, stretch))
         self.dpi = dpi
 
     def ranges(self, start, end):
         from pyglet import font
         for start, end, styles in self.zip_iter.ranges(start, end):
-            font_name, font_size, bold, italic = styles
-            ft = font.load(font_name, font_size,
-                           bold=bool(bold), italic=bool(italic),
-                           dpi=self.dpi)
+            font_name, font_size, bold, italic, stretch = styles
+            ft = font.load(font_name, font_size, bold=bool(bold), italic=bool(italic), stretch=stretch, dpi=self.dpi)
             yield start, end, ft
 
     def __getitem__(self, index):
         from pyglet import font
-        font_name, font_size, bold, italic = self.zip_iter[index]
-        return font.load(font_name, font_size,
-                         bold=bool(bold), italic=bool(italic),
-                         dpi=self.dpi)
+        font_name, font_size, bold, italic, stretch = self.zip_iter[index]
+        return font.load(font_name, font_size, bold=bool(bold), italic=bool(italic), stretch=stretch, dpi=self.dpi)
 
 
-class _NoStyleRangeIterator(object):
+class _NoStyleRangeIterator:
     # XXX subclass runlist
     def ranges(self, start, end):
         yield start, end, None
